from .data import (ikinyarwanda, ibihekane,ibyungo, patterns)
import re
def tokenize(word):
  tokens = []
  tokens = re.compile("\s|a|u|i|e|u|o|â|ê|î|ô|û|[0-9]|[-!$%^&*()_+|~=`\{\}\[\]:\";'<>?,.\/]").split(word)
  for token in patterns:
    if token in word:
      tokens.append(token)
  return [token.strip() for token in tokens if token.strip()]

def detector(syllable):
  if syllable in ikinyarwanda : 
    return True
  return False

def isKinyarwanda(word):
  # print(ikinyarwanda)
  consonants = tokenize(str(word.lower()))
  count = 0.0;
  total = 0.0;
  for consonant in consonants:
    if len(consonant.strip()) > 1 and consonant.strip() not in ibihekane and consonant.strip() not in ibyungo:
      return False
    if len(consonant.strip()) <= 1:
      total += 1
      if detector(consonant.strip()):
        count += 1
  return count == total



import unittest
from rwalang import isKinyarwanda


class TestRwalang(unittest.TestCase):

    def test_kinsentence(self):
        self.assertEqual(isKinyarwanda("Mbifurije umunsi mwiza"), True)
        self.assertEqual(isKinyarwanda(
            "Ikinyarwanda kigizwe n'inyuguti"), True)
        self.assertEqual(isKinyarwanda("500"), True)
        words = ["500", "hello", "array", "holy", "murakoze"]
        self.assertEqual(isKinyarwanda(words[0]), True)
        self.assertEqual(isKinyarwanda(words[1]), False)
        self.assertEqual(isKinyarwanda(words[2]), False)
        self.assertEqual(isKinyarwanda(words[3]), False)
        self.assertEqual(isKinyarwanda(words[4]), True)

    def test_foreignwords(self):
        self.assertEqual(isKinyarwanda(
            "hello"), False)
        self.assertEqual(isKinyarwanda("should behave as expected"), False)

    def test_kinwithponctuations(self):
        self.assertEqual(isKinyarwanda(
            "Ubutinde:Ni uburyo ijambo ritinda"), True)
        self.assertEqual(isKinyarwanda("1) ryama kare "), True)

    def test_kinwithtonations(self):
      words = [
      "gihaânga",
      "Kanâama",
      "Kaanamâ",
      "Gateêra",
      "Mu myandikire ya gihaânga",
    ]
      
      self.assertEqual(isKinyarwanda(words[0]), True)
      self.assertEqual(isKinyarwanda(words[1]), True)
      self.assertEqual(isKinyarwanda(words[2]), True)
      self.assertEqual(isKinyarwanda(words[3]), True)
      self.assertEqual(isKinyarwanda(words[4]), True)
if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python
from setuptools import setup, find_packages
from os import path
here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="rwalang",
    version='0.0.5',
    url="https://github.com/knowbee/pyrwalang.git",
    description="A fast language detection package for Ikinyarwanda(Native language of Rwandans)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    py_modules=["rwalang"],
    packages=find_packages(),
    keywords=["detect language",
              "rwanda",
              "ikinyarwanda",
              "u rwanda"],
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.5",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Operating System :: OS Independent",
    ],
    author='Igwaneza Bruce',
    author_email='knowbeeinc@gmail.com',
    license='MIT',
    zip_safe=False,

)
